@@ -232,10 +232,9 @@ def to_json(xml_document, fp=None, schema=None, cls=None, path=None, converter=N
         kwargs['lazy_decode'] = True
 
     obj = schema.decode(source, path=path, **kwargs)
-
     if isinstance(obj, tuple):
         if fp is not None:
-            json.dump(obj[0], fp, **kwargs)
+            json.dump(obj[0], fp, **json_options)
             obj[1].extend(errors)
             return tuple(obj[1])
         else:
