@@ -11,7 +11,7 @@ from ..exceptions import XMLSchemaValueError
 from ..qnames import XSD_GROUP, XSD_ATTRIBUTE_GROUP, XSD_SEQUENCE, \
     XSD_ALL, XSD_CHOICE, XSD_ANY_ATTRIBUTE, XSD_ATTRIBUTE, XSD_COMPLEX_CONTENT, \
     XSD_RESTRICTION, XSD_COMPLEX_TYPE, XSD_EXTENSION, XSD_ANY_TYPE, \
-    XSD_SIMPLE_CONTENT, XSD_ANY_SIMPLE_TYPE, XSD_OPEN_CONTENT, XSD_ASSERT, \
+    XSD_SIMPLE_CONTENT, XSD_OPEN_CONTENT, XSD_ASSERT, \
     get_qname, local_name, is_not_xsd_annotation, is_xsd_override
 from ..helpers import get_xsd_derivation_attribute
 
@@ -135,6 +135,10 @@ class XsdComplexType(XsdType, ValidationMixin):
         if content_elem is None or content_elem.tag in self._CONTENT_TAIL_TAGS:
             self.content = self.schema.create_empty_content_group(self)
             self._parse_content_tail(elem)
+            default_open_content = self.default_open_content
+            if default_open_content and \
+                    (self.mixed or self.content or default_open_content.applies_to_empty):
+                self.open_content = default_open_content
 
         elif content_elem.tag in {XSD_GROUP, XSD_SEQUENCE, XSD_ALL, XSD_CHOICE}:
             self.content = self.schema.BUILDERS.group_class(content_elem, self.schema, self)
@@ -263,24 +267,24 @@ class XsdComplexType(XsdType, ValidationMixin):
                 self.parse_error("'base' attribute required", elem)
             else:
                 self.parse_error(err, elem)
-            return self.maps.types[XSD_ANY_TYPE]
+            return self.any_type
 
         try:
             base_type = self.maps.lookup_type(base_qname)
         except KeyError:
             self.parse_error("missing base type %r" % base_qname, elem)
             if complex_content:
-                return self.maps.types[XSD_ANY_TYPE]
+                return self.any_type
             else:
-                return self.maps.types[XSD_ANY_SIMPLE_TYPE]
+                return self.any_simple_type
         else:
             if isinstance(base_type, tuple):
                 self.parse_error("circularity definition found between %r "
                                  "and %r" % (self, base_qname), elem)
-                return self.maps.types[XSD_ANY_TYPE]
+                return self.any_type
             elif complex_content and base_type.is_simple():
                 self.parse_error("a complexType ancestor required: %r" % base_type, elem)
-                return self.maps.types[XSD_ANY_TYPE]
+                return self.any_type
 
             if base_type.final and elem.tag.rsplit('}', 1)[-1] in base_type.final:
                 msg = "derivation by %r blocked by attribute 'final' in base type"
@@ -336,7 +340,7 @@ class XsdComplexType(XsdType, ValidationMixin):
             self.parse_error("the base type is not derivable by restriction")
         if base_type.is_simple() or base_type.has_simple_content():
             self.parse_error("base %r is simple or has a simple content." % base_type, elem)
-            base_type = self.maps.types[XSD_ANY_TYPE]
+            base_type = self.any_type
 
         # complexContent restriction: the base type must be a complexType with a complex content.
         for child in filter(is_not_xsd_annotation, elem):
@@ -845,7 +849,9 @@ class Xsd11ComplexType(XsdComplexType):
                     content.append(group)
                     content.elem.append(group.elem)
             else:
-                content = self.schema.create_empty_content_group(self, model='all')
+                content = self.schema.create_empty_content_group(
+                    self, model='all', minOccurs=str(base_type.content.min_occurs)
+                )
                 content.extend(base_type.content)
                 content.elem.extend(base_type.content.elem)
 
@@ -902,7 +908,13 @@ class Xsd11ComplexType(XsdComplexType):
             elem, self.schema, self, **kwargs
         )
 
-        self.assertions = [XsdAssert(e, self.schema, self, self)
-                           for e in elem if e.tag == XSD_ASSERT]
-        if getattr(self.base_type, 'assertions', None):
-            self.assertions.extend(assertion for assertion in self.base_type.assertions)
+        self.assertions = [
+            XsdAssert(e, self.schema, self, self) for e in elem if e.tag == XSD_ASSERT
+        ]
+        try:
+            self.assertions.extend(
+                XsdAssert(assertion.elem, self.schema, self, self)
+                for assertion in self.base_type.assertions
+            )
+        except AttributeError:
+            pass
