@@ -15,11 +15,11 @@ from decimal import Decimal
 from elementpath import XPath2Parser, ElementPathError, XPathContext
 from elementpath.datatypes import AbstractDateTime, Duration
 
-from ..exceptions import XMLSchemaAttributeError, XMLSchemaValueError
-from ..qnames import XSD_GROUP, XSD_SEQUENCE, XSD_ALL, XSD_CHOICE, \
-    XSD_ATTRIBUTE_GROUP, XSD_COMPLEX_TYPE, XSD_SIMPLE_TYPE, \
-    XSD_ALTERNATIVE, XSD_ELEMENT, XSD_ANY_TYPE, XSD_UNIQUE, XSD_KEY, \
-    XSD_KEYREF, XSI_NIL, XSI_TYPE, XSD_ERROR, get_qname, is_not_xsd_annotation
+from ..exceptions import XMLSchemaAttributeError, XMLSchemaTypeError, XMLSchemaValueError
+from ..qnames import XSD_GROUP, XSD_SEQUENCE, XSD_ALL, XSD_CHOICE, XSD_ATTRIBUTE_GROUP, \
+    XSD_COMPLEX_TYPE, XSD_SIMPLE_TYPE, XSD_ALTERNATIVE, XSD_ELEMENT, XSD_ANY_TYPE, \
+    XSD_UNIQUE, XSD_KEY, XSD_KEYREF, XSI_NIL, XSI_TYPE, XSD_ERROR, XSD_NOTATION_TYPE, \
+    get_qname, is_not_xsd_annotation
 from ..etree import etree_element, etree_iter_location_hints
 from ..helpers import get_xsd_derivation_attribute, get_xsd_form_attribute, \
     raw_xml_encode, ParticleCounter, strictly_equal
@@ -125,7 +125,7 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
                 xsd_element = self.maps.lookup_element(self.name)
             except KeyError:
                 self.parse_error('unknown element %r' % self.name)
-                self.type = self.maps.types[XSD_ANY_TYPE]
+                self.type = self.any_type
             else:
                 self.ref = xsd_element
                 self.type = xsd_element.type
@@ -206,13 +206,16 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
                 type_qname = self.schema.resolve_qname(attrib['type'])
             except (KeyError, ValueError, RuntimeError) as err:
                 self.parse_error(err)
-                self.type = self.maps.types[XSD_ANY_TYPE]
+                self.type = self.any_type
             else:
-                try:
-                    self.type = self.maps.lookup_type(type_qname)
-                except KeyError:
-                    self.parse_error('unknown type %r' % attrib['type'])
-                    self.type = self.maps.types[XSD_ANY_TYPE]
+                if type_qname == XSD_ANY_TYPE:
+                    self.type = self.any_type
+                else:
+                    try:
+                        self.type = self.maps.lookup_type(type_qname)
+                    except KeyError:
+                        self.parse_error('unknown type %r' % attrib['type'])
+                        self.type = self.any_type
             finally:
                 child = self._parse_child_component(self.elem, strict=False)
                 if child is not None and child.tag in (XSD_COMPLEX_TYPE, XSD_SIMPLE_TYPE):
@@ -226,7 +229,7 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
                 elif child.tag == XSD_SIMPLE_TYPE:
                     self.type = self.schema.BUILDERS.simple_type_factory(child, self.schema, self)
                 else:
-                    self.type = self.maps.lookup_type(XSD_ANY_TYPE)
+                    self.type = self.any_type
                     return 0
 
                 # Check value constraints
@@ -239,7 +242,7 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
 
                 return 1
             else:
-                self.type = self.maps.lookup_type(XSD_ANY_TYPE)
+                self.type = self.any_type
                 return 0
 
         # Check value constraints
@@ -465,12 +468,13 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
             yield from self.type.iter_components(xsd_classes)
 
     def iter_substitutes(self):
-        for xsd_element in self.maps.substitution_groups.get(self.name, ()):
-            if not xsd_element.abstract:
-                yield xsd_element
-            for e in xsd_element.iter_substitutes():
-                if not e.abstract:
-                    yield e
+        if self.parent is None or self.ref is not None:
+            for xsd_element in self.maps.substitution_groups.get(self.name, ()):
+                if not xsd_element.abstract:
+                    yield xsd_element
+                for e in xsd_element.iter_substitutes():
+                    if not e.abstract:
+                        yield e
 
     def data_value(self, elem):
         """Returns the decoded data value of the provided element as XPath fn:data()."""
@@ -585,6 +589,7 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
 
         inherited = kwargs.get('inherited')
         value = content = attributes = None
+        nilled = False
 
         # Get the instance effective type
         xsd_type = self.get_type(elem, inherited)
@@ -629,7 +634,7 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
                 reason = "element is not nillable."
                 yield self.validation_error(validation, reason, elem, **kwargs)
             elif xsi_nil not in {'0', '1', 'false', 'true'}:
-                reason = "xsi:nil attribute must has a boolean value."
+                reason = "xsi:nil attribute must have a boolean value."
                 yield self.validation_error(validation, reason, elem, **kwargs)
             elif xsi_nil in ('0', 'false'):
                 pass
@@ -640,16 +645,15 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
                 reason = "xsi:nil='true' but the element is not empty."
                 yield self.validation_error(validation, reason, elem, **kwargs)
             else:
-                if converter is not None:
-                    element_data = ElementData(elem.tag, None, None, attributes)
-                    yield converter.element_decode(element_data, self, xsd_type, level)
-                return
+                nilled = True
 
         if xsd_type.is_empty() and elem.text:
             reason = "character data is not allowed because content is empty"
             yield self.validation_error(validation, reason, elem, **kwargs)
 
-        if xsd_type.model_group is not None:
+        if nilled:
+            pass
+        elif xsd_type.model_group is not None:
             for assertion in xsd_type.assertions:
                 for error in assertion(elem, **kwargs):
                     yield self.validation_error(validation, error, **kwargs)
@@ -697,6 +701,15 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
                 else:
                     value = text
 
+            elif xsd_type.is_notation():
+                if xsd_type.name == XSD_NOTATION_TYPE:
+                    msg = "cannot validate against xs:NOTATION directly, " \
+                          "only against a subtype with an enumeration facet"
+                    yield self.validation_error(validation, msg, text, **kwargs)
+                elif not xsd_type.enumeration:
+                    msg = "missing enumeration facet in xs:NOTATION subtype"
+                    yield self.validation_error(validation, msg, text, **kwargs)
+
             if text is None:
                 for result in content_decoder.iter_decode('', validation, **kwargs):
                     if isinstance(result, XMLSchemaValidationError):
@@ -738,26 +751,33 @@ class XsdElement(XsdComponent, ValidationMixin, ParticleMixin, ElementPathMixin)
 
         # Collects fields values for identities that refer to this element.
         for identity, counter in identities.items():
-            if not counter.enabled or self not in identity.elements:
+            if not counter.enabled:
+                continue
+            elif self in identity.elements:
+                xsd_element = self
+            elif self.ref in identity.elements:
+                xsd_element = self.ref
+            else:
                 continue
 
             try:
                 if xsd_type is self.type:
-                    xsd_fields = identity.elements[self]
+                    xsd_fields = identity.elements[xsd_element]
                     if xsd_fields is None:
-                        xsd_fields = identity.elements[self] = identity.get_fields(self)
+                        xsd_fields = identity.get_fields(xsd_element)
+                        identity.elements[xsd_element] = xsd_fields
                 else:
                     xsd_element = self.copy()
                     xsd_element.type = xsd_type
                     xsd_fields = identity.get_fields(xsd_element)
 
-                if all(fld is None for fld in xsd_fields):
+                if all(x is None for x in xsd_fields):
                     continue
                 fields = identity.get_fields(elem, namespaces, decoders=xsd_fields)
-            except XMLSchemaValueError as err:
+            except (XMLSchemaValueError, XMLSchemaTypeError) as err:
                 yield self.validation_error(validation, err, elem, **kwargs)
             else:
-                if any(fld is not None for fld in fields):
+                if any(x is not None for x in fields) or nilled:
                     try:
                         counter.increase(fields)
                     except ValueError as err:
@@ -1107,9 +1127,10 @@ class Xsd11Element(XsdElement):
             yield from self.type.iter_components(xsd_classes)
 
     def iter_substitutes(self):
-        for xsd_element in self.maps.substitution_groups.get(self.name, ()):
-            yield xsd_element
-            yield from xsd_element.iter_substitutes()
+        if self.parent is None or self.ref is not None:
+            for xsd_element in self.maps.substitution_groups.get(self.name, ()):
+                yield xsd_element
+                yield from xsd_element.iter_substitutes()
 
     def get_type(self, elem, inherited=None):
         if not self.alternatives:
@@ -1249,16 +1270,20 @@ class XsdAlternative(XsdComponent):
         except (KeyError, ValueError, RuntimeError) as err:
             if 'type' in attrib:
                 self.parse_error(err)
-                self.type = self.maps.lookup_type(XSD_ANY_TYPE)
+                self.type = self.any_type
             else:
                 child = self._parse_child_component(self.elem, strict=False)
                 if child is None or child.tag not in (XSD_COMPLEX_TYPE, XSD_SIMPLE_TYPE):
                     self.parse_error("missing 'type' attribute")
-                    self.type = self.maps.lookup_type(XSD_ANY_TYPE)
+                    self.type = self.any_type
                 elif child.tag == XSD_COMPLEX_TYPE:
                     self.type = self.schema.BUILDERS.complex_type_class(child, self.schema, self)
                 else:
                     self.type = self.schema.BUILDERS.simple_type_factory(child, self.schema, self)
+
+                if not self.type.is_derived(self.parent.type):
+                    msg = "declared type is not derived from {!r}"
+                    self.parse_error(msg.format(self.parent.type))
         else:
             try:
                 self.type = self.maps.lookup_type(type_qname)
