@@ -14,9 +14,9 @@ import re
 import math
 import operator
 from collections.abc import MutableSequence
-from elementpath import XPath2Parser, ElementPathError
-from elementpath.datatypes import XSD_BUILTIN_TYPES
+from elementpath import XPath2Parser, XPathContext, ElementPathError
 
+from ..etree import etree_element
 from ..qnames import XSD_LENGTH, XSD_MIN_LENGTH, XSD_MAX_LENGTH, XSD_ENUMERATION, \
     XSD_INTEGER, XSD_WHITE_SPACE, XSD_PATTERN, XSD_MAX_INCLUSIVE, XSD_MAX_EXCLUSIVE, \
     XSD_MIN_INCLUSIVE, XSD_MIN_EXCLUSIVE, XSD_TOTAL_DIGITS, XSD_FRACTION_DIGITS, \
@@ -738,6 +738,7 @@ class XsdAssertionFacet(XsdFacet):
         </assertion>
     """
     _ADMITTED_TAGS = {XSD_ASSERTION}
+    _root = etree_element('root')
 
     def __repr__(self):
         return '%s(test=%r)' % (self.__class__.__name__, self.path)
@@ -751,17 +752,18 @@ class XsdAssertionFacet(XsdFacet):
             self.path = 'true()'
 
         try:
-            builtin_type_name = self.base_type.primitive_type.local_name
-            variables = {'value': XSD_BUILTIN_TYPES[builtin_type_name].value}
+            variable_types = {'value': self.base_type.primitive_type.prefixed_name}
         except AttributeError:
-            variables = {'value': XSD_BUILTIN_TYPES['anySimpleType'].value}
+            variable_types = {'value': self.any_simple_type.prefixed_name}
 
         if 'xpathDefaultNamespace' in self.elem.attrib:
             self.xpath_default_namespace = self._parse_xpath_default_namespace(self.elem)
         else:
             self.xpath_default_namespace = self.schema.xpath_default_namespace
-        self.parser = XsdAssertionXPathParser(self.namespaces, strict=False, variables=variables,
-                                              default_namespace=self.xpath_default_namespace)
+        self.parser = XsdAssertionXPathParser(
+            self.namespaces, strict=False, variable_types=variable_types,
+            default_namespace=self.xpath_default_namespace
+        )
 
         try:
             self.token = self.parser.parse(self.path)
@@ -770,9 +772,9 @@ class XsdAssertionFacet(XsdFacet):
             self.token = self.parser.parse('true()')
 
     def __call__(self, value):
-        self.parser.variables['value'] = value
+        context = XPathContext(self._root, variables={'value': value})
         try:
-            if not self.token.evaluate():
+            if not self.token.evaluate(context):
                 msg = "value is not true with test path %r."
                 yield XMLSchemaValidationError(self, value, reason=msg % self.path)
         except ElementPathError as err:
