@@ -46,7 +46,7 @@ from .exceptions import XMLSchemaParseError, XMLSchemaValidationError, XMLSchema
 from .xsdbase import check_validation_mode, XsdValidator, ValidationMixin, XsdComponent
 from .notations import XsdNotation
 from .identities import XsdKey, XsdKeyref, XsdUnique, Xsd11Key, Xsd11Unique, Xsd11Keyref
-from .facets import XSD_11_FACETS
+from .facets import XSD_10_FACETS, XSD_11_FACETS
 from .simple_types import xsd_simple_type_factory, XsdUnion, XsdAtomicRestriction, \
     Xsd11AtomicRestriction, Xsd11Union
 from .attributes import XsdAttribute, XsdAttributeGroup, Xsd11Attribute
@@ -183,11 +183,14 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
     :type timeout: int
     :param build: defines whether build the schema maps. Default is `True`.
     :type build: bool
-    :param use_meta: if `True` the schema processor uses the package meta-schema, \
+    :param use_meta: if `True` the schema processor uses the validator meta-schema, \
     otherwise a new meta-schema is added at the end. In the latter case the meta-schema \
     is rebuilt if any base namespace has been overridden by an import. Ignored if the \
     argument *global_maps* is provided.
     :type use_meta: bool
+    :param use_fallback: if `True` the schema processor uses the validator fallback \
+    location hints to load well-known namespaces (eg. xhtml).
+    :type use_fallback: bool
     :param loglevel: for setting a different logging level for schema initialization \
     and building. For default is WARNING (30). For INFO level set it with 20, for \
     DEBUG level with 10. The default loglevel is restored after schema building, \
@@ -204,8 +207,8 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
     :vartype BUILDERS_MAP: dict
     :cvar BASE_SCHEMAS: a dictionary from namespace to schema resource for meta-schema bases.
     :vartype BASE_SCHEMAS: dict
-    :cvar FALLBACK_LOCATIONS: fallback schema location hints for other standard namespaces.
-    :vartype FALLBACK_LOCATIONS: dict
+    :cvar fallback_locations: fallback schema location hints for other standard namespaces.
+    :vartype fallback_locations: dict
     :cvar meta_schema: the XSD meta-schema instance.
     :vartype meta_schema: XMLSchema
     :cvar attribute_form_default: the schema's *attributeFormDefault* attribute. \
@@ -273,7 +276,7 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
     BUILDERS = None
     BUILDERS_MAP = None
     BASE_SCHEMAS = None
-    FALLBACK_LOCATIONS = None
+    fallback_locations = None
     meta_schema = None
 
     # Schema defaults
@@ -292,11 +295,16 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
 
     def __init__(self, source, namespace=None, validation='strict', global_maps=None,
                  converter=None, locations=None, base_url=None, allow='all', defuse='remote',
-                 timeout=300, build=True, use_meta=True, loglevel=None):
+                 timeout=300, build=True, use_meta=True, use_fallback=True, loglevel=None):
         super(XMLSchemaBase, self).__init__(validation)
         ElementPathMixin.__init__(self)
 
         if loglevel is not None:
+            if isinstance(loglevel, str):
+                level = loglevel.strip().upper()
+                if level in {'DEBUG', 'INFO', 'WARN', 'WARNING', 'ERROR', 'CRITICAL'}:
+                    loglevel = getattr(logging, level)
+
             logger.setLevel(loglevel)
         elif build and global_maps is None:
             logger.setLevel(logging.WARNING)
@@ -380,6 +388,8 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
 
         self.locations = NamespaceResourcesMap(self.source.get_locations(self.extra_locations))
         self.converter = self.get_converter(converter)
+        if not use_fallback:
+            self.fallback_locations = {}
 
         if self.meta_schema is None:
             # Meta-schema creation phase (MetaXMLSchema class)
@@ -404,7 +414,7 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
         else:
             raise XMLSchemaTypeError("'global_maps' argument must be an %r instance." % XsdGlobals)
 
-        if self.XSD_VERSION > '1.0' and any(ns == VC_NAMESPACE for ns in self.namespaces.values()):
+        if any(ns == VC_NAMESPACE for ns in self.namespaces.values()):
             # For XSD 1.1+ apply versioning filter to schema tree. See the paragraph
             # 4.2.2 of XSD 1.1 (Part 1: Structures) definition for details.
             # Ref: https://www.w3.org/TR/xmlschema11-1/#cip
@@ -752,20 +762,23 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
 
     def create_any_type(self):
         """
-        Creates an xs:anyType instance related to schema instance.
+        Creates an xs:anyType equivalent type related with the wildcards
+        connected to global maps of the schema instance in order to do a
+        correct namespace lookup during wildcards validation.
         """
+        schema = self.meta_schema or self
         any_type = self.BUILDERS.complex_type_class(
             elem=etree_element(XSD_COMPLEX_TYPE, name=XSD_ANY_TYPE),
-            schema=self,
-            parent=None,
-            mixed=True
+            schema=schema, parent=None, mixed=True, block='', final=''
         )
         any_type.content.append(self.BUILDERS.any_element_class(
-            ANY_ELEMENT, self, any_type.content
+            ANY_ELEMENT, schema, any_type.content
         ))
         any_type.attributes[None] = self.BUILDERS.any_attribute_class(
-            ANY_ATTRIBUTE_ELEMENT, self, any_type.attributes
+            ANY_ATTRIBUTE_ELEMENT, schema, any_type.attributes
         )
+        any_type.maps = any_type.content.maps = any_type.content[0].maps = \
+            any_type.attributes[None].maps = self.maps
         return any_type
 
     def create_element(self, name, text=None, **attrib):
@@ -1091,8 +1104,8 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
                 if local_hints:
                     locations = local_hints + locations
 
-            if namespace in self.FALLBACK_LOCATIONS:
-                locations.append(self.FALLBACK_LOCATIONS[namespace])
+            if namespace in self.fallback_locations:
+                locations.append(self.fallback_locations[namespace])
 
             self._import_namespace(namespace, locations)
 
@@ -1183,7 +1196,7 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
     def version_check(self, elem):
         """
         Checks if the element is compatible with the version of the validator and XSD
-        types/facets availability.
+        types/facets availability. Invalid vc attributes are not detected in XSD 1.0.
 
         :param elem: an Element of the schema.
         :return: `True` if the schema element is compatible with the validator, \
@@ -1192,15 +1205,17 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
         if VC_MIN_VERSION in elem.attrib:
             vc_min_version = elem.attrib[VC_MIN_VERSION]
             if not XSD_VERSION_PATTERN.match(vc_min_version):
-                self.parse_error("invalid attribute vc:minVersion value", elem)
-            elif vc_min_version > '1.1':
+                if self.XSD_VERSION > '1.0':
+                    self.parse_error("invalid attribute vc:minVersion value", elem)
+            elif vc_min_version > self.XSD_VERSION:
                 return False
 
         if VC_MAX_VERSION in elem.attrib:
             vc_max_version = elem.attrib[VC_MAX_VERSION]
             if not XSD_VERSION_PATTERN.match(vc_max_version):
-                self.parse_error("invalid attribute vc:maxVersion value", elem)
-            elif vc_max_version <= '1.1':
+                if self.XSD_VERSION > '1.0':
+                    self.parse_error("invalid attribute vc:maxVersion value", elem)
+            elif vc_max_version <= self.XSD_VERSION:
                 return False
 
         if VC_TYPE_AVAILABLE in elem.attrib:
@@ -1228,22 +1243,32 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
         if VC_FACET_AVAILABLE in elem.attrib:
             for qname in elem.attrib[VC_FACET_AVAILABLE].split():
                 try:
-                    if self.resolve_qname(qname) not in XSD_11_FACETS:
-                        return False
+                    facet_name = self.resolve_qname(qname)
                 except XMLSchemaNamespaceError:
                     pass
                 except (KeyError, ValueError) as err:
                     self.parse_error(str(err), elem)
+                else:
+                    if self.XSD_VERSION == '1.0':
+                        if facet_name not in XSD_10_FACETS:
+                            return False
+                    elif facet_name not in XSD_11_FACETS:
+                        return False
 
         if VC_FACET_UNAVAILABLE in elem.attrib:
             for qname in elem.attrib[VC_FACET_UNAVAILABLE].split():
                 try:
-                    if self.resolve_qname(qname) not in XSD_11_FACETS:
-                        break
+                    facet_name = self.resolve_qname(qname)
                 except XMLSchemaNamespaceError:
                     break
                 except (KeyError, ValueError) as err:
                     self.parse_error(err, elem)
+                else:
+                    if self.XSD_VERSION == '1.0':
+                        if facet_name not in XSD_10_FACETS:
+                            break
+                    elif facet_name not in XSD_11_FACETS:
+                        break
             else:
                 return False
 
@@ -1285,6 +1310,12 @@ class XMLSchemaBase(XsdValidator, ValidationMixin, ElementPathMixin, metaclass=X
             namespace, local_name = self.namespaces.get('', ''), qname
 
         if not namespace:
+            if namespace_imported and self.target_namespace and '' not in self.imports:
+                raise XMLSchemaNamespaceError(
+                    "the QName {!r} is mapped to no namespace, but this requires "
+                    "that there is an xs:import statement in the schema without "
+                    "the 'namespace' attribute.".format(qname)
+                )
             return local_name
         elif namespace_imported and self.meta_schema is not None and \
                 namespace != self.target_namespace and \
@@ -1693,7 +1724,7 @@ class XMLSchema10(XMLSchemaBase):
         XML_NAMESPACE: os.path.join(SCHEMAS_DIR, 'xml_minimal.xsd'),
         XSI_NAMESPACE: os.path.join(SCHEMAS_DIR, 'XMLSchema-instance_minimal.xsd'),
     }
-    FALLBACK_LOCATIONS = LOCATION_HINTS
+    fallback_locations = LOCATION_HINTS.copy()
 
 
 class XMLSchema11(XMLSchemaBase):
@@ -1753,9 +1784,9 @@ class XMLSchema11(XMLSchemaBase):
         XML_NAMESPACE: os.path.join(SCHEMAS_DIR, 'xml_minimal.xsd'),
         XSI_NAMESPACE: os.path.join(SCHEMAS_DIR, 'XMLSchema-instance_minimal.xsd'),
         XSD_NAMESPACE: os.path.join(SCHEMAS_DIR, 'XSD_1.1/xsd11-extra.xsd'),
-        VC_NAMESPACE: os.path.join(SCHEMAS_DIR, 'XMLSchema-versioning_minimal.xsd'),
+        VC_NAMESPACE: os.path.join(SCHEMAS_DIR, 'XMLSchema-versioning.xsd'),
     }
-    FALLBACK_LOCATIONS = LOCATION_HINTS
+    fallback_locations = LOCATION_HINTS.copy()
 
     def _parse_inclusions(self):
         super(XMLSchema11, self)._parse_inclusions()
